summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/parameters/RosegardenParameterBox.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/parameters/RosegardenParameterBox.h')
-rw-r--r--src/gui/editors/parameters/RosegardenParameterBox.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/editors/parameters/RosegardenParameterBox.h b/src/gui/editors/parameters/RosegardenParameterBox.h
index c75f875..459aeab 100644
--- a/src/gui/editors/parameters/RosegardenParameterBox.h
+++ b/src/gui/editors/parameters/RosegardenParameterBox.h
@@ -55,7 +55,7 @@ class RosegardenParameterBox : public TQFrame
public:
RosegardenParameterBox(const TQString &shortLabel, // e.g. i18n("Track")
const TQString &longLabel, // e.g. i18n("Track Parameters")
- TQWidget *tqparent = 0,
+ TQWidget *parent = 0,
const char *name = 0);
// Ask for a one-word string that can be used to label the widget.
@@ -75,8 +75,8 @@ protected:
// List the tqlayout styles that may be requested via a call to setStyle().
enum LayoutMode {
- LANDSCAPE_MODE, // Optimize the tqlayout for a tall and narrow tqparent.
- PORTRAIT_MODE // Optimize the tqlayout for a short and wide tqparent.
+ LANDSCAPE_MODE, // Optimize the tqlayout for a tall and narrow parent.
+ PORTRAIT_MODE // Optimize the tqlayout for a short and wide parent.
};
void setLayoutMode(LayoutMode mode);